import collections
import stats

def reg_overlap((b1,e1),(b2,e2)):
    if b1<=b2 and b2<e1:
        return min(e1,e2)-b2
    if b2<=b1 and b1<e2:
        return min(e1,e2)-b1
    return 0

class bed:
    def __init__(self):
        self._bed=collections.defaultdict(list)

    def __getitem__(self,item):
        return self._bed[item]
    def includes(self,ch,pos):
	res=self.bin_srch(ch,pos)
        beg,end=res[1]
        if beg<=pos and pos<=end:
            return True
        else:
            return False
        
    def from_file(self,f):
        return self.from_list([ln.strip().split() for ln in f])

    def from_wiggle(self,f):
        return self.from_list([ln.strip().split() for ln in f][1:])
        
    def from_list(self,l):
        for rec in l:
            chr,beg,end=rec[:3]
            labels=rec[3:]
            self._bed[chr].append(((int(beg),int(end)),labels))
        for l in self._bed.values():
            l.sort()
        return self
    
    def extend(self,left=100,right=100):
        for chr,l in self._bed.items():
            self._bed[chr]=[((b-left,e+right),lab) for ((b,e),lab) in l]
            
                
    def to_gff(self,f,src="bed2gff",feature="region"):
        f.write("##gff-version 3\n##bed2gff conversion\n") #header
        for chr,l in self._bed.items():
            for (beg,end),lab in l:
                f.write("%s\t%s\t%s\t%d\t%d\t%f\t%s\t.\t%s\n"%(chr,src,feature,beg,end,lab[4],lab[3],lab[5]))

    def to_file(self,f,name=None):
        for chr,l in self._bed.items():
            for (beg,end),lab in l:
                if name==None:
                    n=lab
                else:
                    n=name
                f.write("%s\t%d\t%d\t%s\n"%(chr,beg,end,n))
            
    def from_gff(self,f,type=None,prefix="chr"):
        self.names={}
        self.prefix=prefix
        for ln in f:
            if ln[0]=="#" or ln=="\n":
                continue
            if ln[0]==">": # fasta part begins
                break
            rec=ln.strip().split("\t")
            if type and rec[2]!=type: #if type!=None select only stuff that matches type
                continue
            try:
                data=dict([d.split("=") for d in rec[-1].split(";")])
            except ValueError:
                data=dict([d.split("=") for d in rec[-1].split(";")[:-1]][0:1])
            try:
                val=float(rec[5])
            except ValueError:
                val=0.0
            out=(prefix+rec[0].lower(),int(rec[3]),int(rec[4]),rec[6],val,data,data["ID"].lower())
            #print out
            self.names[out[-1]]=out[:-1]
            self._bed[out[0]].append((out[1:3],out))

        return self

    def from_crms(self,crms):
        import data
        for c in crms:
            beg,end,chr=data.crm2loc[c][:3]
            self._bed["chr"+chr].append(((beg,end),[c]))
        for chr,l in self._bed.items():
            l.sort()
        return self

    def bin_srch(self,chr,v,b=0,e=None):
        l=map(lambda x: x[0],self._bed[chr])
        if e==None:
            e=len(l)-1
        while b<e-1:
            i=(b+e)/2
            if l[i][1]<v:
                b=i
            elif l[i][0]>v:
                e=i
            else:
                return i,l[i]
        if l==[]:
            return 0,None
        return b,l[b]


    def bed_difference(self,bed2,bool=True,ret_bed=False):
        tri=0
        ovr=0
        bed_res=bed()
        for chr,l in self._bed.items():
            for (beg,end),label in l:
                #print beg,end,tri,ovr
                if bool:
                    tri+=1
                else:
                    tri+=end-beg
                (i,match)=bed2.bin_srch(chr,(beg+end)/2)
                if match==None or not (reg_overlap((beg,end),match) or (i+1<len(bed2[chr]) and reg_overlap((beg,end),bed2[chr][i+1][0]))):
                                           
                    if bool:
                        ovr_cur=1
                    else:
                        ovr_cur=end-beg
                    if ovr_cur>0:
                        ovr+=ovr_cur
                        bed_res[chr].append(((beg,end),label))

        if ret_bed:
            return bed_res
        return tri,ovr,1.0*ovr/tri

    def bed_overlap(self,bed2,bool=True,ret_bed=False):
        tri=0
        ovr=0
        bed_res=bed()
        for chr,l in self._bed.items():
            for (beg,end),label in l:
                #print beg,end,tri,ovr
                if bool:
                    tri+=1
                else:
                    tri+=end-beg
                (i,match)=bed2.bin_srch(chr,(beg+end)/2)
                if match!=None:
                    if bool:
                        if reg_overlap((beg,end),match) or (i+1<len(bed2[chr]) and reg_overlap((beg,end),bed2[chr][i+1][0])):
                            ovr_cur=1
                        else:
                            ovr_cur=0
                    else:
                        ovr_cur=reg_overlap((beg,end),match)
                        if i+1<len(bed2[chr]):
                            ovr_cur+=reg_overlap((beg,end),bed2[chr][i+1][0])
                    if ovr_cur>0:
                        ovr+=ovr_cur
                        bed_res[chr].append(((beg,end),label))

        if ret_bed:
            return bed_res
        try:
            frac=1.0*ovr/tri
        except ValueError:
            frac=None
        return tri,ovr,frac

    def len_stats(self):
        l=[]
        for chr in self._bed.keys():
           l.extend([r[0][1]-r[0][0] for r in self._bed[chr]])
        print len(l),sum(l),min(l),max(l),stats.mean(l),stats.stdev(l)

    def get_fasta(self,files):
        pass
