#GS="TAIR8_GFF3_genes.gff"
GS="TAIR/gff/TAIR10_GFF3_genes_transposons.gff"
#GS="/media/bartek/My Passport/data/Agronomics/TAIR/TAIR10_GFF3_genes_transposons.gff"
#GS=r"c:\Users\bartek\Dropbox\code\Agronomics\plotter\TAIR10_GFF3_genes_transposons.gff"
GS="pombe_09052011.gff"

import collections,numpy

def mean(l):
    if l==[]:
        return float("NaN")
    else:
        return 1.*sum(l)/len(l)

def median(l):
    if l==[]:
        return float("NaN")
    else:
        return l[len(l)/2]

def trim(x,low=-.3,high=.3):
    if x>high:
        return high
    if x<low:
        return low
    return x

def split_feat_by_len(feat,l=2000):
    res_s=collections.defaultdict(list)
    res_l=collections.defaultdict(list)
    for c in feat:
	for f in feat[c]:
	    if abs(f[0]-f[1])>l:
		res_l[c].append(f)
	    else: # len<=l
		res_s[c].append(f)
    return res_s,res_l

def report_overlaps(gs,bed,prefix,up=2000,down=1000):
    gs_in,gs_up,gs_down,regs_in,regs_up,regs_down=gene_overlap(gs,bed,up,down)
    regs_all=all_from_bed(bed)
    regs_not=[reg for reg in regs_all if reg not in regs_in|regs_down|regs_up]
    f=open("%s-%d+%d-upstream.csv"%(prefix,up,down),"w")
    for g in gs_up:
        f.write("%s\n"%g)
    f.close()
    f=open("%s-%d+%d-downstream.csv"%(prefix,up,down),"w")
    for g in gs_down:
        f.write("%s\n"%g)
    f.close()
    f=open("%s-%d+%d-inside.csv"%(prefix,up,down),"w")
    for g in gs_in:
        f.write("%s\n"%g)
    f.close()
    f=open("%s-%d+%d-intergenic.csv"%(prefix,up,down),"w")
    for r in regs_not:
        f.write("%s\t%d\t%d\n"%(r[0],r[1][0],r[1][1]))
    f.close()


def all_from_bed(bed):
    res=[]
    for k,v in bed._bed.items():
        for x in v:
            res.append((k,x[0]))
    return res

def gene_overlap(gs,bed,up=2000,down=1000):
    gs_in=set()
    gs_up=set()
    gs_down=set()
    regs_in=set()
    regs_up=set()
    regs_down=set()
    direc={"+":1,"-":-1}
    
    def fix(x,chr):
        return (chr,x[0])#,tuple(x[1]))

    for chr in gs:
        for start,stop,strand,g in gs[chr]:
            i,(beg_i,end_i)=bed.bin_srch(chr,start)
            begs=[beg_i]
            ends=[end_i]
            if i>0:
                beg,end=bed._bed[chr][i-1][0]
                begs.append(beg)
                ends.append(end)
            if i<len(bed._bed[chr]):
                beg,end=bed._bed[chr][i+1][0]
                begs.append(beg)
                ends.append(end)
            i,(beg_i,end_i)=bed.bin_srch(chr,stop)
            begs+=[beg_i]
            ends+=[end_i]
            if i>0:
                beg,end=bed._bed[chr][i-1][0]
                begs.append(beg)
                ends.append(end)
            if i<len(bed._bed[chr]):
                beg,end=bed._bed[chr][i+1][0]
                begs.append(beg)
                ends.append(end)
            dir=direc[strand]
            for pos in begs+ends:
                if (pos>=start and pos<=stop) or (pos<=start and pos>=stop):
                    #inside
                    gs_in.add(g)
                    regs_in.add(fix(bed._bed[chr][bed.bin_srch(chr,pos)[0]],chr))
                    
                elif (pos>=start and pos<=start-dir*up) or (pos<=start and pos>=start-dir*up):
                    #upstream
                    gs_up.add(g)
                    regs_up.add(fix(bed._bed[chr][bed.bin_srch(chr,pos)[0]],chr ))
                elif (pos>=stop and pos<=stop+dir*down) or (pos<=stop and pos>=stop+dir*down):
                    #downstream
                    gs_down.add(g)                   
                    regs_down.add(fix(bed._bed[chr][bed.bin_srch(chr,pos)[0]],chr))
                    
            # if g in gs_in:
            #     print g,start,stop,strand, bed.bin_srch(chr,pos),chr,pos,begs,ends

            for b,e in zip(begs,ends):
                #print b,e
                if (start>=b and start<=e) or (start<=b and start>=e):
                    #print g,start
                    gs_in.add(g)
                    regs_in.add(fix(bed._bed[chr][bed.bin_srch(chr,b)[0]],chr))
                    gs_up.add(g)
                    regs_up.add(fix(bed._bed[chr][bed.bin_srch(chr,b)[0]],chr))
                if (stop>=b and stop<=e) or (stop<=b and stop>=e):
                    #print g,stop
                    gs_in.add(g)
                    regs_in.add(fix(bed._bed[chr][bed.bin_srch(chr,b)[0]],chr))
                    gs_down.add(g)
                    regs_down.add(fix(bed._bed[chr][bed.bin_srch(chr,b)[0]],chr))
                    
    return gs_in,gs_up,gs_down,regs_in,regs_up,regs_down

def smooth(p,band=1):
    res=[]
    for i,x in enumerate(p):
        res.append(mean([p[j] for j in range (max(0,i-band),min(len(p),i+band))]))
    return res


def read_features_bed(f):
    f=open(f)
    result=collections.defaultdict(list)
    for ln in f:
	rec=ln.strip().split("\t")
	ch=rec[0]
	beg=int(rec[1])
	end=int(rec[2])
	name=rec[3]
	strand=rec[4]
	result[ch].append((beg,end,strand,name))
    return result
		
def read_features(f=GS,feature="gene",coords=False):
    f=open(f)
    res=collections.defaultdict(list)
    for ln in f:
        rec=ln.strip().split("\t")
        if rec[2]==feature:
            try:
                name=rec[-1].split(";")[0].split("=")[1].split(":")[-1]
                #name=rec[-1].split(";")[0].split()[-1]
            except IndexError:
                print rec[-1].split(";")[0].split()[-1]
                a=bn
            if coords:
                name+="-"+rec[3]+"-"+rec[4]
            ch,start,stop,strand=rec[0].lower(),int(rec[3]),int(rec[4]),rec[6]
            if strand=="-":
                start,stop=stop,start
            res[ch].append((start,stop,strand,name))
    return res

def density(ftr,res=100000):
    from collections import defaultdict 
    result={}
    for chr in ftr:
	result[chr]=defaultdict(int)
	for x in ftr[chr]:
	    pos=(x[0]+x[1])/2
	    bin=int(pos/res)*res
	    result[chr][bin]+=1
    return result

def density_plot(ftr,ch,res=200000,normed=True,label=""):
    import pylab
    result=density(ftr,res)
    if normed:
	norm=sum(result[ch].values())*1.
    else:
	norm=1.0
    xs=sorted(result[ch].keys())
    ys=[result[ch][x]/norm for x in xs]
    pylab.plot(xs,ys,label=label)
    return ys

def density_map(ftr,ch,res=200000,normed=True,label="",width=10,tick=1000000,cmap="winter",inter=None):
    import pylab
    result=density(ftr,res)
    if normed:
	norm=sum(result[ch].values())*1.
    else:
	norm=1.0
    xs=sorted(result[ch].keys())
    ys=[result[ch][x]/norm for x in xs]
    ar=pylab.array(ys*width).reshape((width,len(ys)))
    pylab.imshow(ar,cmap=pylab.get_cmap(cmap),interpolation=inter)
    ticks=pylab.arange(len(xs)*res/tick)
    pylab.xticks(ticks*tick/res,map(str,list(ticks)))
    pylab.yticks([],[])
    
def avg_signal(signal,resol):
    i=0
    begin=0
    cur=[]
    res={}
    import scipy
    while i < len(signal):
	pos,val=signal[i]
	if pos>begin+resol: # new bin
	    res[begin]=scipy.mean(cur)
	    begin+=resol
	    cur=[val]
	else:
	    cur.append(val)
	i+=1
    res[begin]=scipy.mean(cur)
    return res

def signal_map(sgr,ch,res=200000,normed=True,label="",width=10,tick=1000000,cmap="winter",inter=None,cent=None):
    import pylab
    result=avg_signal(sgr[ch],res)
    xs=sorted(result.keys())
    ys=[result[x] for x in xs]
    ar=pylab.array(ys*width).reshape((width,len(ys)))
    pylab.imshow(ar,cmap=pylab.get_cmap(cmap),interpolation=inter)
    ticks=pylab.arange(len(xs)*res/tick)
    tlabs=map(str,list(ticks))
    ticks=list(ticks*tick/res)
    if cent:
	ticks.append(cent[ch]*1./res)
	tlabs.append("C")
    pylab.xticks(ticks,tlabs)
    
    pylab.yticks([],[])


def read_genes(f=GS):
    return read_features(f,"gene")

def read_introns(f=GS):
    return read_features(f,"intron")

def read_exons(f=GS):
    return read_features(f,"exon",coords=True)

def read_cds(f=GS):
    return read_features(f,"CDS")

def read_3prime(f=GS):
    return read_features(f,"three_prime_UTR")
def read_5prime(f=GS):
    return read_features(f,"five_prime_UTR")

def read_sgr(sgr):
    res=collections.defaultdict(list)
    for ln in open(sgr):
        rec=ln.strip().split()
        try:
            res[rec[0].lower()].append((int(rec[1]),float(rec[2])))
        except:
            print rec
    return res

def read_expr(exp,chr,start,end,strand,fun=mean):
    if start>end:
        return read_expr(exp,chr,end,start,strand)
    p1=find(start,chr,exp[strand])
    p2=find(end,chr,exp[strand])
    lst=exp[strand][chr]
    return fun(map(lambda x:x[1],lst[p1:p2]))

def generate_gene_expr(cds,exp):
    import collections
    gcds=collections.defaultdict(list)
    for chr,lst in cds.items():
	for beg,end,strand,n in lst:
	    name=n.split(".")[0]
	    if beg>end:
		end,beg=beg,end
	    p1=find(beg,chr,exp[strand])
	    p2=find(end,chr,exp[strand])
	    gcds[name].extend(exp[strand][chr][p1:p2])
    res={}
    for g,l in gcds.items():
	res[g]=mean(map(lambda x:x[1],l))
    return res

def get_signal(feats,sgr):
    res=[]
    for ch,fs in feats.items():
        ch=ch.lower()
        for rec in fs:
            beg=find(rec[0],ch,sgr)
            end=find(rec[1],ch,sgr)
            res.extend(map(lambda x:x[1],sgr[ch][beg:end]))
    return res
        
def get_signals(feats,sgr):
    res=[]
    for ch,fs in feats.items():
        ch=ch.lower()
        for rec in fs:
            beg=find(rec[0],ch,sgr)
            end=find(rec[1],ch,sgr)
	    vs=map(lambda x:x[1],sgr[ch][beg:end])
	    if vs:
		res.append(vs)
		       
    return res
        
def find(pos,ch,sgr):
    lst=sgr[ch]
    l=0
    h=len(lst)
    while l+1<h:
        #print l,h,
        m=(l+h)/2
        i=lst[m][0]
        #print m,i
            
        if i>pos:
            h=m
        elif i<pos:
            l=m
        else:
            l=m
            h=m
    return (l+h)/2

def get_probe(sgr,ch,pos):
    i=find(pos,ch,sgr)
    try:
        return sgr[ch][i]
    except:
        print ch,pos,i
    
    
def find_interval(pos,lst):
    """finding a position in an interaval list like the feature list"""
    l=0
    h=len(lst)
    if h==0:
        return -1
    while l+1<h:
        #print l,h,
        m=(l+h)/2
        i=min(lst[m][0:2])
        #print m,i
            
        if i>pos:
            h=m
        elif i<pos:
            l=m
        else:
            l=m
            h=m
    ftr=lst[(l+h)/2][0:2]
    if pos>=min(ftr) and pos<=max(ftr):
        return (l+h)/2
    else:
        return -1

def get_env(chr,pos,strand,sgr,binsize,before,after,):
    start=find(pos-before*binsize,chr,sgr)-1
    lst=sgr[chr]
    res=[]
    cur=[]
    bound=pos-before*binsize
    count=before+after+1
    p=start
    v=0
    while count>0:
        try:
            p,v=lst[start]
        except IndexError:
            #we ran out of data
            
            p+=25
            
        #print start,bound,count,p,v,cur,res
        if p<bound:
            cur.append(v)
        else: #passed the bound
            res.append(mean(cur))
            cur=[v]
            bound+=binsize
            count-=1
        start+=1
    if strand=="+":
        return res[1:]
    else:
        return list(reversed(res[1:]))
    
def process_genes(genes,sgr,binsize=100,before=6,after=6,subset=[],tss=True,tts=True):
    res=[]
    for chr in genes:
        for (start,stop,strand,name) in genes[chr]:
            if (subset) and (name not in subset):
                continue
            if tss:
                fprime=get_env(chr.lower(),start,strand,sgr,binsize,before,after)
            else:
                fprime=[]
            if tts:
                tprime=get_env(chr.lower(),stop,strand,sgr,binsize,before,after)
            else:
                tprime=[]
            res.append(fprime+tprime)
    return res
    

def expr_dict(genes,exp,fun=mean):
    res={}
    vals=[]
    for chr in genes:
        for (start,stop,strand,name) in genes[chr]:
           v=read_expr(exp,chr.lower(),start,stop,strand,fun=fun)
           if not v>0 and not v<0: #NaN
               continue
           vals.append(v)
           res[name]=v
    return res,list(sorted(vals))

def strand_dict(genes):
    res={}
    for chr in genes:
        for (start,stop,strand,name) in genes[chr]:
           res[name]=strand
    return res

def antisense_dict(genes,exp):
    res={}
    vals=[]
    anti={"+":"-","-":"+"}
    for chr in genes:
        for (start,stop,strand,name) in genes[chr]:
           v=read_expr(exp,chr.lower(),start,stop,anti[strand])
           if not v>0 and not v<0: #NaN
               continue
           vals.append(v)
           res[name]=v
    return res,list(sorted(vals))

def around_dict(genes,exp,up=500,down=500):
    res={}
    vals=[]

    for chr in genes:
        for (start,stop,strand,name) in genes[chr]:
            if strand=="+":
                v_up=read_expr(exp,chr.lower(),start-up,start,strand)
                v_down=read_expr(exp,chr.lower(),stop,stop+down,strand)
            if strand=="-":
                v_up=read_expr(exp,chr.lower(),stop,stop+up,strand)
                v_down=read_expr(exp,chr.lower(),start-down,start,strand)
            if (not v_up>0 and not v_up<0) or (not v_down>0 and not v_down<0): #NaN
                continue
            vals.append((v_up,v_down))
            res[name]=(v_up,v_down)
    return res,list(sorted(vals))

def occu_dict(genes,sgr):
    res={}
    vals=[]
    for chr in genes:
        for (start,stop,strand,name) in genes[chr]:
            v=mean(get_env(chr.lower(),start,strand,sgr,100,1,1))
            if not v>0 and not v<0: #NaN
               continue
            vals.append(v)
            res[name]=v
    return res,list(sorted(vals))


def give_names(gene_d,high,low):
    res=[]
    for g,v in gene_d.items():
        if high>v and low<v:
            res.append((v,g))
    return map(lambda x:x[1],sorted(res,reverse=True))

def heatmap(gs,subs,sgrs,binsize=50,before=20,after=20):
    import pylab

    for x,s in enumerate(sgrs):
        for y,sub in enumerate(subs):
            pylab.subplot(len(subs),len(sgrs),len(sgrs)*y+x+1)
            pylab.title(str(len(sgrs)*y+x+1))
            pv=process_genes(gs,s,binsize=binsize,before=before,after=after,subset=subs)
            pylab.imshow(numpy.array(map(lambda x: map(trim,smooth(x,band=1)),pv[:100])),cmap=pylab.cm.PiYG,interpolation=None,aspect=.2)

def plot_profs(gs,subsets,sgrs,labels,binsize=50,before=20,after=20,band=2,split=False,tss=True,tts=True):
    import pylab

    for i,(subs,sgr,l) in enumerate(zip(subsets,sgrs,labels)):
	col_r=i*1.0/len(labels)
	col_g=1.-i*1.0/len(labels)
	col_b=0.
	col_a=1.
        pv=process_genes(gs,sgr,binsize=binsize,before=before,after=after,subset=subs,tss=tss,tts=tts)
        if not split:
            pylab.plot(smooth(map(mean,zip(*pv)),band=band),label=l)#,color=(col_r,col_g,col_b,col_a))
            pylab.xticks([0,before-.5,before+after-.5,2*before+after-.5,2*(before+after)-1],["-3k","5'","+3k| -3k","3'","+3k"])
#    pylab.ylim(-5,5)
            pylab.plot([before+after-.5]*2,[-1500,1500],"k")
            pylab.plot([before-.5,before-.5,2*before+after-.5,2*before+after-.5],[-1500,1500,1500,-1500],"k--")

        else:
            pylab.subplot(121)
            pylab.plot(smooth(map(mean,zip(*pv)),band=band),label=l)#,color=(col_r,col_g,col_b,col_a))
            pylab.xticks([0,before-.5,before+after-.5],["-1k","5'","+1k"])
            pylab.plot([before+after-.5]*2,[-1500,1500],"k")
            pylab.xlim(0,before+after-.5)

            pylab.subplot(122)
            pylab.plot(smooth(map(mean,zip(*pv)),band=band),label=l)#,color=(col_r,col_g,col_b,col_a))
            pylab.xticks([before+after-.5,2*before+after-.5,2*(before+after)-1],["-1k","3'","+1k"])
            pylab.plot([before+after-.5]*2,[-1500,1500],"k")
            pylab.xlim(before+after-.5,2*(before+after)-1)
            
def plot_data(data,labels,binsize=50,before=20,after=20,band=2,split=False):
    import pylab

    for i,(pv,l) in enumerate(zip(data,labels)):
	col_r=i*1.0/len(labels)
	col_g=1.-i*1.0/len(labels)
	col_b=0.
	col_a=1.
        
        if not split:
            pylab.plot(smooth(map(mean,zip(*pv)),band=band),label=l)#,color=(col_r,col_g,col_b,col_a))
            pylab.xticks([0,before-.5,before+after-.5,2*before+after-.5,2*(before+after)-1],["-3k","5'","+3k| -3k","3'","+3k"])
#    pylab.ylim(-5,5)
            pylab.plot([before+after-.5]*2,[-1500,1500],"k")
            pylab.plot([before-.5,before-.5,2*before+after-.5,2*before+after-.5],[-1500,1500,1500,-1500],"k--")

        else:
            pylab.subplot(121)
            pylab.plot(smooth(map(mean,zip(*pv)),band=band),label=l)#,color=(col_r,col_g,col_b,col_a))
            pylab.xticks([0,before-.5,before+after-.5],["-1k","5'","+1k"])
            pylab.plot([before+after-.5]*2,[-1500,1500],"k")
            pylab.xlim(0,before+after-.5)

            pylab.subplot(122)
            pylab.plot(smooth(map(mean,zip(*pv)),band=band),label=l)#,color=(col_r,col_g,col_b,col_a))
            pylab.xticks([before+after-.5,2*before+after-.5,2*(before+after)-1],["-1k","3'","+1k"])
            pylab.plot([before+after-.5]*2,[-1500,1500],"k")
            pylab.xlim(before+after-.5,2*(before+after)-1)
                        
    
def dotplot(gs,subsets,sgrs,labels):
    import pylab
    print "computing occupancy"
    od=occu_dict(gs,sgr)
    for i,(subs,sgr,l) in enumerate(zip(subsets,sgrs,labels)):
	col_r=i*1.0/len(labels)
	col_g=1.-i*1.0/len(labels)
	col_b=0.
	col_a=1.
	#pylab.plot(
	

def plot_avgs(gs,subsets,sgrs,labels,binsize=50,bef=30,band=2,bottom=-.3,avg=0):
    import pylab

    for i,(subs,sgr,l) in enumerate(zip(subsets,sgrs,labels)):
        pv=process_genes(gs,sgr,binsize=binsize,before=bef,after=bef,subset=subs)
	col_r=i*1.0/len(labels)
	col_g=1.-i*1.0/len(labels)
	col_b=0.
	col_a=1.
	pylab.bar(i, mean(map(mean,zip(*pv)))-bottom, width=0.8,color=(col_r,col_g,col_b,col_a), bottom=bottom)
        #pylab.plot(,band=band),label=l,color=(col_r,col_g,col_b,col_a))
	
    pylab.xticks(pylab.arange(len(labels))+.4,labels)
    #    pylab.ylim(-.25,.2)
    #    pylab.plot([39.5,39.5],[-15,15],"k")
    pylab.plot([-1,len(labels)+1],[avg,avg],"k--")
    pylab.xlim(0,len(labels))

def plot_tss(gs,subsets,sgrs,labels,binsize=50,before=50,after=50,band=2):
    import pylab

    for i,(subs,sgr,l) in enumerate(zip(subsets,sgrs,labels)):
        pv=process_genes(gs,sgr,binsize=binsize,before=before,after=after,subset=subs,tts=False)
	col_r=i*1.0/len(labels)
	col_g=1.-i*1.0/len(labels)
	col_b=0.
	col_a=1.
        pylab.plot(smooth(map(mean,zip(*pv)),band=band),label=l,color=(col_r,col_g,col_b,col_a))
    pylab.xticks([0,49.5,99.5],["-5k","TSS","+5k"])
    pylab.ylim(-.25,.2)
    pylab.plot([99.5,99.5],[-15,15],"k--")
#    pylab.plot([19.5,19.5,59.5,59.5],[-15,15,15,-15],"k--")


def find_peaks(gs,subset,sgrs,binsize=50,before=5,after=5):
    res=[]
    for s in sgrs:
        profs=process_genes(gs,s,binsize=binsize,before=before,after=after,subset=subset)
        profs=map(lambda x: x[:before+after],profs)
        maxs=map(max,profs)
        indexs=map(lambda x,y:x.index(y), profs,maxs)
        res.append(indexs)
    return res
        
# def make_plots():
# sgr=read_sgr("ChipChip/ChipChipData/avg_over_input/H3_6-8.both.sgr") # H3 stress
# sgr2=read_sgr("ChipChip/ChipChipData/avg_over_input/H1_1-5.both.sgr") #H1.1 stress
# sgr3=read_sgr("ChipChip/ChipChipData/avg_over_input/H1_6-8.both.sgr") #H1.3 stress
# sgr4=read_sgr("ChipChip/ChipChipData/avg_over_input/H1_18-20.both.sgr") #H1.1 normal
# sgr5=read_sgr("ChipChip/ChipChipData/avg_over_input/H3_22-36.both.sgr") #H3 normal
# sgr6=read_sgr("ChipChip/ChipChipData/avg_over_input/H1_25-28.both.sgr") #H1.2 normal
# sgr7=read_sgr("ChipChip/ChipChipData/avg_over_input/H1_10-12.both.sgr") #H1.2 stress 
# sgr8=read_sgr("ChipChip/ChipChipData/avg_over_input/H1_3n.both.sgr") #H1.3 normal

# sgr_h3s=read_sgr("TAIR9_H3_6-8.both.sgr")  #h3stress
# sgr_h11s=read_sgr("TAIR9_H1_1-5.both.sgr") #H1.1 stress
# sgr_h13s=read_sgr("TAIR9_H1_6-8.both.sgr") #H1.3 stress
# sgr_h12s=read_sgr("TAIR9_H1_10-12.both.sgr") #H1.2 stress 

# sgr_h11=read_sgr("TAIR9_H1_18-20.both.sgr") #H1.1 normal
# sgr_h3=read_sgr("TAIR9_H3_22-36.both.sgr") #H3 normal
# sgr_h12=read_sgr("TAIR9_H1_25-28.both.sgr") #H1.2 normal
# sgr_h13=read_sgr("TAIR9_H1_3n.both.sgr") #H1.3 normal 


# exp_S=read_sgr("rawData/H13/AGRONOMICS1/normalized/mean/WT,NS.mean.S.sgr")
# exp_A=read_sgr("rawData/H13/AGRONOMICS1/normalized/mean/WT,NS.mean.A.sgr")

# exp_ll_S=read_sgr("rawData/H13/AGRONOMICS1/normalized/mean/WT,S.mean.S.sgr")
# exp_ll_A=read_sgr("rawData/H13/AGRONOMICS1/normalized/mean/WT,S.mean.A.sgr")

# exp_dif_S=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/wt,S-NS.S.sgr")
# exp_dif_A=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/wt,S-NS.A.sgr")
# exp_ko_S=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/KO,S-NS.S.sgr")
# exp_ko_A=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/KO,S-NS.A.sgr")
# exp_k_S=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/WT,S-KO,S.S.sgr")
# exp_k_A=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/WT,S-KO,S.A.sgr")

# exp_dif={"+":exp_dif_S,"-":exp_dif_A}
# exp_ko={"+":exp_ko_S,"-":exp_ko_A}
# exp_k={"+":exp_k_S,"-":exp_k_A}
# exp_anti={"-":exp_S,"+":exp_A}
# exp={"+":exp_S,"-":exp_A}

# gs=read_genes()

# edd,evd=expr_dict(gs,exp_dif)
# edk,evk=expr_dict(gs,exp_k)
# ed,ev=expr_dict(gs,exp)
# eda,eva=expr_dict(gs,exp_anti)

# subs_no=give_names(edd,.05,-.05)
# subs_up=give_names(edd,20,5)
# subs_down=give_names(edd,-5,-20)

# subs_no=give_names(edk,.1,-.1)
# subs_up=give_names(edk,20,5)
# subs_down=give_names(edk,-5,-20)

# import pylab
# pylab.figure()
# pylab.subplot(1,3,1)
# plot_profs(gs,[subs_down]*7,[sgr5,sgr,sgr3,sgr4,sgr2,sgr6,sgr7],["H3","H3 ll","H1.3 ll","H1.1","H1.1 ll", "H1.2","H1.2 ll"],band=1)
# pylab.title("down-regulated")
# pylab.ylim(-.3,.3)
# subplot(1,3,2)
# plot_profs(gs,[subs_no]*7,[sgr5,sgr,sgr3,sgr4,sgr2,sgr6,sgr7],["H3","H3 ll","H1.3 ll","H1.1","H1.1 ll", "H1.2","H1.2 ll"],band=1)
# pylab.title("not-regulated")
# pylab.ylim(-.3,.3)
# subplot(1,3,3)
# plot_profs(gs,[subs_up]*7,[sgr5,sgr,sgr3,sgr4,sgr2,sgr6,sgr7],["H3","H3 ll","H1.3 ll","H1.1","H1.1 ll", "H1.2","H1.2 ll"],band=1)
# pylab.title("up-regulated")
# pylab.ylim(-.3,.3)
# legend(loc="lower right")

# # pylab.figure()
# # pylab.subplot(1,3,1)
# # plot_profs(gs,[subs_down]*3,[sgr3,sgr2,sgr],["h1.3","h1.1","h3"],band=1)
# # pylab.title("down-regulated")
# # subplot(1,3,2)
# # plot_profs(gs,[subs_no]*3,[sgr3,sgr2,sgr],["h1.3","h1.1","h3"],band=1)
# # pylab.title("not-regulated")
# # subplot(1,3,3)
# # plot_profs(gs,[subs_up]*3,[sgr3,sgr2,sgr],["h1.3","h1.1","h3"],band=1)
# # pylab.title("up-regulated")



# subs100_20=give_names(ed,100,10)
# subs20_10=give_names(ed,20,10)
# subs10_5=give_names(ed,10,5)
# #subs5_2=give_name
# exp_dif_S=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/wt,S-NS.S.sgr")
# exp_dif_A=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/wt,S-NS.A.sgr")
# exp_ko_S=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/KO,S-NS.S.sgr")
# exp_ko_A=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/KO,S-NS.A.sgr")
# exp_k_S=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/WT,S-KO,S.S.sgr")
# exp_k_A=read_sgr("rawData/H13/AGRONOMICS1/normalized/signed_t-test/WT,S-KO,S.A.sgr")

# exp_dif={"+":exp_dif_S,"-":exp_dif_A}
# exp_ko={"+":exp_ko_S,"-":exp_ko_A}
# exp_k={"+":exp_k_S,"-":exp_k_A}
# exp_anti={"-":exp_S,"+":exp_A}
# exp={"+":exp_S,"-":exp_A}

# gs=read_genes()

# edd,evd=expr_dict(gs,exp_dif)
# edk,evk=expr_dict(gs,exp_k)
# ed,ev=expr_dict(gs,exp)
# eda,eva=expr_dict(gs,exp_anti)

# subs_no=give_names(edd,.05,-.05)
# subs_up=give_names(edd,20,5)
# subs_down=give_names(edd,-5,-20)

# subs_no=give_names(edk,.1,-.1)
# subs_up=give_names(edk,20,5)
# subs_down=give_names(edk,-5,-20)
# s(ed,5,2)
# subs2_05=give_names(ed,2,05)
# subs1_05=give_names(ed,1,.5)
# subs05_02=give_names(ed,.5,.2)





# pylab.figure()
# pylab.subplot(2,4,1)
# plot_profs(gs,[subs100_20,subs20_10,subs10_5,subs5_2,subs2_1,subs1_05,subs05_02],[sgr3]*7,["20+","10-20","5-10","2-5","1-2","0.5-1","0-0.5"],band=1)
# #plot_profs(gs,[subs100_20,subs10_5,subs2_1,subs05_02],[sgr3]*4,["20+","5-10","1-2","0-0.5"],band=1)
# pylab.title("H1.3 ll")
# pylab.ylim(-.2,.05)
# # pylab.subplot(1,4,2)
# # plot_profs(gs,[subs100_20,subs10_5,subs2_1,subs05_02],[sgr2]*4,["20+","5-10","1-2","0-0.5"],band=1)
# # pylab.title("H1.1 ll")

# # pylab.subplot(1,4,3)
# # plot_profs(gs,[subs100_20,subs10_5,subs2_1,subs05_02],[sgr4]*4,["20+","5-10","1-2","0-0.5"],band=1)
# # pylab.title("H1.1")

# pylab.subplot(2,4,7)
# plot_profs(gs,[subs100_20,subs20_10,subs10_5,subs5_2,subs2_1,subs1_05,subs05_02],[sgr7]*7,["20+","10-20","5-10","2-5","1-2","0.5-1","0-0.5"],band=1)
# pylab.title("H1.2 ll")
# pylab.ylim(-.25,.1)

# # pylab.subplot(2,4,3)
# # plot_profs(gs,[subs100_20,subs20_10,subs10_5,subs5_2,subs2_1,subs1_05,subs05_02],[sgr6]*7,["20+","10-20","5-10","2-5","1-2","0.5-1","0-0.5"],band=1)
# # pylab.title("H1.2")

# pylab.subplot(2,4,5)
# plot_profs(gs,[subs100_20,subs20_10,subs10_5,subs5_2,subs2_1,subs1_05,subs05_02],[sgr]*7,["20+","10-20","5-10","2-5","1-2","0.5-1","0-0.5"],band=1)
# pylab.title("H3 ll")
# pylab.ylim(-.05,.3)

# pylab.subplot(1,4,4)
# plot_profs(gs,[subs100_20,subs10_5,subs2_1,subs05_02],[sgr5]*4,["20+","5-10","1-2","0-0.5"],band=1)
# pylab.title("H3")


